import type {
  ArrayStats,
  AttributeStats,
  AttributeType,
  BooleanStats,
  CategoricalStats,
  NumericalStats,
  ObjectStats,
  TemporalStats,
} from 'ts-common';
import {
  updateArrayStats,
  updateCategoricalStats,
  updateNumericalStats,
  updateObjectStats,
  updateTemporalStats,
  updateBooleanStats,
} from './attributeStats';

// Update statistics based on attribute type and value
export const updateStatistics = (attribute: AttributeStats<AttributeType>, value: any) => {
  switch (attribute.attributeType) {
    case 'number':
      updateNumericalStats(attribute.statistics as NumericalStats, value);
      break;
    case 'string':
      updateCategoricalStats(attribute.statistics as CategoricalStats, value);
      break;
    case 'boolean':
      updateBooleanStats(attribute.statistics as BooleanStats, value);
      break;
    case 'datetime':
    case 'timestamp':
    case 'date':
    case 'time':
      updateTemporalStats(attribute.statistics as TemporalStats, value);
      break;
    case 'array':
      updateArrayStats(attribute.statistics as ArrayStats, value);
      break;
    case 'object':
      updateObjectStats(attribute.statistics as ObjectStats, value);
      break;
  }
};

