import { RabbitMqBroker, RabbitMqConnection, RedisConnector } from 'ts-common';
import { REDIS_PASSWORD, REDIS_HOST, REDIS_PORT, RABBIT_USER, RABBIT_PASSWORD, RABBIT_PORT, RABBIT_HOST, rabbitMq } from './variables';
import { log } from './logger';
import { queryServiceReader } from './readers/queryService';
import { insightProcessor } from './readers/insightProcessor';


async function main() {
    log.info('Starting query-service...');

    log.info('Connecting to RabbitMQ...');
    const frontendPublisher = await new RabbitMqBroker(rabbitMq, 'ui-direct-exchange').connect();
    const mlPublisher = await new RabbitMqBroker(rabbitMq, 'ml-direct-exchange', "query-service", undefined, { autoDelete: false }, { autoDelete: false }).connect();
    log.info('Connected to RabbitMQ!');

    log.info('Connecting to Redis...');
    const redis = new RedisConnector(REDIS_PASSWORD, REDIS_HOST, REDIS_PORT);
    await redis.connect();
    log.info('Connected to Redis!');

    queryServiceReader(frontendPublisher, mlPublisher, redis, 'neo4j');
    insightProcessor();
    // TODO: other query services for other databases

    log.info('Connected to RabbitMQ!');
}

main();
